GroupBox
================================

.. currentmodule:: enaml.widgets.group_box

.. autoclass:: GroupBox


Backends
--------

Qt
^^

.. inheritance-diagram::
    enaml.widgets.qt.qt_group_box.QtGroupBox
    :parts: 1

.. autoclass:: enaml.widgets.qt.qt_group_box.QtGroupBox

Wx
^^

.. inheritance-diagram::
    enaml.widgets.wx.wx_group_box.WXGroupBox
    :parts: 1

.. autoclass:: enaml.widgets.wx.wx_group_box.WXGroupBox
